@@ -1,9 +1,12 @@
-import {
+// Copyright (c) cdr4eelz
+// Distributed under the terms of the Modified BSD License.
+
+  import {
   JupyterFrontEnd,
   JupyterFrontEndPlugin
 } from '@jupyterlab/application';
 
-import { ISettingRegistry } from '@jupyterlab/settingregistry';
+//import { ISettingRegistry } from '@jupyterlab/settingregistry';
 
 import { requestAPI } from './handler';
 
@@ -14,9 +17,13 @@ const plugin: JupyterFrontEndPlugin<void> = {
   id: 'serialhub:plugin',
   autoStart: true,
   optional: [],
+/*
   activate: (app: JupyterFrontEnd, settingRegistry: ISettingRegistry | null) => {
+*/
+  activate: (app: JupyterFrontEnd) => {
     console.log('JupyterLab extension serialhub is activated!');
 
+    /*
     if (settingRegistry) {
       settingRegistry
         .load(plugin.id)
@@ -27,6 +34,7 @@ const plugin: JupyterFrontEndPlugin<void> = {
           console.error('Failed to load settings for serialhub.', reason);
         });
     }
+    */
 
     requestAPI<any>('get_example')
       .then(data => {
